@@ -1,7 +1,7 @@
 package Class::Accessor::Array;
 
-our $DATE = '2016-03-28'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-08-27'; # DATE
+our $VERSION = '0.030'; # VERSION
 
 sub import {
     my ($class0, $spec) = @_;
@@ -31,7 +31,7 @@ sub import {
             *{"$caller\::$constructor"} = eval $code_str;
             die if $@;
         };
-    };
+    }
 }
 
 1;
@@ -49,7 +49,7 @@ Class::Accessor::Array - Generate accessors/constructor for array-based object
 
 =head1 VERSION
 
-This document describes version 0.02 of Class::Accessor::Array (from Perl distribution Class-Accessor-Array), released on 2016-03-28.
+This document describes version 0.030 of Class::Accessor::Array (from Perl distribution Class-Accessor-Array), released on 2017-08-27.
 
 =head1 SYNOPSIS
 
@@ -57,6 +57,7 @@ In F<lib/Your/Class.pm>:
 
  package Your::Class;
  use Class::Accessor::Array {
+     # constructor => 'new',
      accessors => {
          foo => 0,
          bar => 1,
@@ -79,6 +80,30 @@ C<$obj> is now:
 
 This module is a builder for array-backed classes.
 
+You can change the constructor name from the default C<new> using the
+C<constructor> parameter.
+
+Currently the built constructor does not accept parameters to set the
+attributes, e.g.:
+
+ my $obj = Your::Class->new(foo=>1, bar=>2); # not supported
+
+You have to set the attributes manually:
+
+ # supported
+ my $obj = Your::Class->new;
+ $obj->foo(1);
+ $obj->bar(2);
+
+If you subclass from another class that uses L<Class::Accessor::Array>, you must
+make sure that you choose an index that has not already been used (unless you
+deliberately want to share storage space with an existing attribute).
+
+Note that if you're looking to reduce memory storage usage, an object based on
+Perl array is not that much-more-space-efficient compared to the hash-based
+object. Try representing an object as a pack()-ed string instead using
+L<Class::Accessor::PackedString>.
+
 =for Pod::Coverage .+
 
 =head1 HOMEPAGE
@@ -99,8 +124,11 @@ feature.
 
 =head1 SEE ALSO
 
+L<Class::Accessor::PackedString> and L<Class::Accessor::PackedString::Fields>.
+
 Other class builders for array-backed objects: L<Class::XSAccessor::Array>,
-L<Class::ArrayObjects>, L<Object::ArrayType::New>.
+L<Class::Accessor::Array::Glob>, L<Class::ArrayObjects>,
+L<Object::ArrayType::New>.
 
 =head1 AUTHOR
 
@@ -108,7 +136,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
